==> webkit2gtk_2.35.1.orig.tar.xz: webkitgtk-2.35.1/Source/WebKit/Shared/WebGPU/WebGPURenderPassColorAttachment.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(GPU_PROCESS)

#include "WebGPUColor.h"
#include "WebGPUIdentifier.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPULoadOp.h>
#include <pal/graphics/WebGPU/WebGPUStoreOp.h>
#include <variant>
#include <wtf/Ref.h>
#include <wtf/Vector.h>

namespace WebKit::WebGPU {

struct RenderPassColorAttachment {
    WebGPUIdentifier view;
    WebGPUIdentifier resolveTarget;

    std::variant<PAL::WebGPU::LoadOp, Vector<double>, ColorDict> loadValue;
    PAL::WebGPU::StoreOp storeOp;

    template<class Encoder> void encode(Encoder& encoder) const
    {
        encoder << view;
        encoder << resolveTarget;
        encoder << loadValue;
        encoder << storeOp;
    }

    template<class Decoder> static std::optional<RenderPassColorAttachment> decode(Decoder& decoder)
    {
        std::optional<WebGPUIdentifier> view;
        decoder >> view;
        if (!view)
            return std::nullopt;

        std::optional<WebGPUIdentifier> resolveTarget;
        decoder >> resolveTarget;
        if (!resolveTarget)
            return std::nullopt;

        std::optional<std::variant<PAL::WebGPU::LoadOp, Vector<double>, ColorDict>> loadValue;
        decoder >> loadValue;
        if (!loadValue)
            return std::nullopt;

        std::optional<PAL::WebGPU::StoreOp> storeOp;
        decoder >> storeOp;
        if (!storeOp)
            return std::nullopt;

        return { { WTFMove(*view), WTFMove(*resolveTarget), WTFMove(*loadValue), WTFMove(*storeOp) } };
    }
};

} // namespace WebKit::WebGPU

#endif // ENABLE(GPU_PROCESS)

==> webkit2gtk_2.35.2.orig.tar.xz: webkitgtk-2.35.2/Source/WebKit/Shared/WebGPU/WebGPURenderPassColorAttachment.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(GPU_PROCESS)

#include "WebGPUColor.h"
#include "WebGPUIdentifier.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPULoadOp.h>
#include <pal/graphics/WebGPU/WebGPUStoreOp.h>
#include <variant>
#include <wtf/Ref.h>
#include <wtf/Vector.h>

namespace WebKit::WebGPU {

struct RenderPassColorAttachment {
    WebGPUIdentifier view;
    WebGPUIdentifier resolveTarget;

    std::variant<PAL::WebGPU::LoadOp, Vector<double>, ColorDict> loadValue;
    PAL::WebGPU::StoreOp storeOp { PAL::WebGPU::StoreOp::Store };

    template<class Encoder> void encode(Encoder& encoder) const
    {
        encoder << view;
        encoder << resolveTarget;
        encoder << loadValue;
        encoder << storeOp;
    }

    template<class Decoder> static std::optional<RenderPassColorAttachment> decode(Decoder& decoder)
    {
        std::optional<WebGPUIdentifier> view;
        decoder >> view;
        if (!view)
            return std::nullopt;

        std::optional<WebGPUIdentifier> resolveTarget;
        decoder >> resolveTarget;
        if (!resolveTarget)
            return std::nullopt;

        std::optional<std::variant<PAL::WebGPU::LoadOp, Vector<double>, ColorDict>> loadValue;
        decoder >> loadValue;
        if (!loadValue)
            return std::nullopt;

        std::optional<PAL::WebGPU::StoreOp> storeOp;
        decoder >> storeOp;
        if (!storeOp)
            return std::nullopt;

        return { { WTFMove(*view), WTFMove(*resolveTarget), WTFMove(*loadValue), WTFMove(*storeOp) } };
    }
};

} // namespace WebKit::WebGPU

#endif // ENABLE(GPU_PROCESS)
